#!/bin/bash
# shellcheck disable=SC1091 # Cannot resolve paths in variables

PROJECT_HOME="$(realpath -s --relative-to . "$(dirname "$0")/..")" || exit
. "$PROJECT_HOME/scripts/util.sh" || exit

APP="$1"
TYPE="$2"

if [[ -z "$APP" ]] || [[ -z "$TYPE" ]]
then
	error $"Usage: $0 <app name> <type>"
fi

case "$TYPE" in
dev|release) ;;
*) error $"$TYPE must be 'dev' or 'release'";;
esac

get_arch

DESC_FILE="$PROJECT_HOME/swu/${APP}_app.desc"
OUT_SWU="$PROJECT_HOME/swu/$TYPE.swu"

gen_swu() {
	declare -a desc_files=(
		"$DESC_FILE"
	)

	[ -e "$DESC_FILE" ] \
		|| error $"$DESC_FILE not found, bad app $APP ?"

	# Increase version to allow upgrade
	mkswu --update-version "$DESC_FILE" \
		|| error $"Could not increase $DESC_FILE version -- is mkswu up to date?"

	# This variable is used in the desc file
	export ARCH

	case "$TYPE" in
	dev)
		# enable sshd on armadillo
		desc_files+=(
			"$PROJECT_HOME/swu/enable_sshd.desc"
		)
		# and also remove known hosts in case of reinstall
		rm -f "$PROJECT_HOME/config/ssh_known_hosts"
		;;
	esac

	# merge all desc contents together in order to share
	# same version, which would be reset with different files
	cat "${desc_files[@]}" \
		| mkswu -o "$OUT_SWU" - \
		|| exit
}

"$PROJECT_HOME/scripts/build_container_image.sh" "$APP" || exit
gen_swu

echo $"Install $OUT_SWU on Armadillo next"
