#!/bin/bash
# shellcheck disable=SC2034 # Variables declared this file are used elsewhere

# localization
TEXTDOMAIN=scripts
TEXTDOMAINDIR="${PROJECT_HOME:-.}/scripts/locale"

error() {
	printf "%s\n" "$@"
	exit 1
}

get_arch() {
	ARCH=$(jq -r .arch "${PROJECT_HOME:-.}/info.json")
	[ -n "$ARCH" ] \
		|| error $"Could not read arch from info.json" \
			$"info.json should have been created at project creation, please recreate" \
			$"the project from ABOSDE and contact support if this does not help."
}

get_carch() {
	[ -n "$ARCH" ] || get_arch
	case "$ARCH" in
	arm64|aarch64) CARCH="arm64v8";;
	armv7) CARCH="arm32v7";;
	armhf) CARCH="arm32v6";;
	x86_64) CARCH="amd64";;
	*) error $"Got invalid arch: $ARCH";;
	esac
}

get_product() {
	PRODUCT=$(jq -r .product "${PROJECT_HOME:-.}/info.json")
	[ -n "$PRODUCT" ] \
		|| error $"Could not read product from info.json" \
			$"info.json should have been created at project creation, please recreate" \
			$"the project from ABOSDE and contact support if this does not help."
}

prompt_yesno() {
	local default="$1"
	shift 1
	local yesno

	while true; do
		read -r -p "$1" yesno
		[ -n "$yesno" ] || yesno="$default"
		case "$yesno" in
		[Yy]|[Yy][Ee][Ss]|[Tt][Rr][Uu][Ee]|1)
			return 0;;
		[Nn]|[Nn][Oo]|[Ff][Aa][Ll][Ss][Ee]|0)
			return 1;;
		esac
	done
}

kill_app() {
	local container="$1"

	ssh -F config/ssh_config Armadillo "podman kill $container"
}

copy_run() {
	local source dest container

	[ "$#" -lt 2 ] && return
	source=$1
	dest=$2
	shift 2

	# copy to dest without removing dest dir (breaks volume)
	tar -C "$source" -cz . \
		| ssh -F config/ssh_config Armadillo '
			d='"${dest@Q}"';
			find "$d" -mindepth 1 -delete && tar -C "$d" -xz'

	# Copy only -- stop here.
	[ "$#" = 0 ] && return
	container="$1"

	ssh -F config/ssh_config Armadillo "podman_start $container \
		&& podman logs -f $container"
}
